/*
  Persistence of Vision Ray Tracer Scene Description File

  Sea demo from the "Sea Buoy" scene.

  Requires Lightsys 4.

  --   
  Jaime Vives Piqueres, Nov 2006.

*/

// ***************
// *** globals ***
// ***************
global_settings{
 //max_trace_level 3 
 assumed_gamma 1.0 
}
#default{texture{finish{ambient 0}}}


// *************************
// *** standard includes ***
// *************************
#include "colors.inc"
#include "textures.inc"
#include "functions.inc"


// *******************************
// *** CIE & LIGHTSYS includes ***
// *******************************
#include "CIE.inc"
#include "lightsys.inc"          
#declare Lightsys_Brightness=1;
// change white point to typical outdoor white balance
CIE_ColorSystemWhitepoint(sRGB_ColSys,Daylight2Whitepoint(5500))


// ***************
// *** globals ***
// ***************
#declare Landscape_Size=1000; // side of the seascape square 
#declare r_sun   = seed(8124); // seed for random sun placement
#declare r_water = seed(8034); // water surface seed


// ****************************
// *** sun & sky parameters ***
// ****************************
// skylight params:
#declare Current_Turbidity=3; // skylight turbidity (influences haze)
#declare Intensity_Mult =.75; // skylight intensity
#declare Max_Vertices  =1000; // skylight mesh resolution
#declare Sun_Size      =5000; // aparent size of the sun
// sun placement settings (uses rand seed if these are not specified)
//#declare Az   =120;
//#declare Al   = 50;
//#declare North=-z;
// haze params:
#declare use_atmosphere=1; // use haze?
#declare Haze_Height   =1; // full height 
#declare Haze_Distance=40; // turbidity also affects distance
#declare Haze_Tint     =2; // 0=Sky color, 1=Sun color, 2=Horizon color
#declare use_ambient   =0; // fill lihts


// ************************
// *** water parameters ***
// ************************
#declare Water_Height =1;  // water level
#declare Water_Surface=1;  // 1=isosurface, 2=plane with normal


// call the includes
#include "i_sky.inc"
#include "i_water.inc"        


// **************
// *** camera ***
// **************
camera{ 
 location <0,(Water_Height+1),-Landscape_Size*.49>
 up 0.000024*y right 0.000032*x
 direction .000050*z
 look_at <0,0,-Landscape_Size*.48>
 rotate -30*y
}


